#
# Copyright (C) 2020-2025 Soleta Networks <info@soleta.eu>
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License as published by the
# Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.

from PyQt6.QtWidgets import QWidget, QVBoxLayout, QLabel, QFrame
from PyQt6.QtCore import Qt, QTimer
from src.utils.net import *
import os


INFO_POLLING_INTERVAL = 10000

class ClientInfoWidget(QFrame):
    def __init__(self, parent=None):
        super().__init__(parent)
        self.setFrameStyle(QFrame.Shape.StyledPanel | QFrame.Shadow.Plain)

        layout = QVBoxLayout(self)
        layout.setAlignment(Qt.AlignmentFlag.AlignCenter)

        self.client_ip_label = QLabel()
        layout.addWidget(self.client_ip_label)

        self.client_mac_label = QLabel()
        layout.addWidget(self.client_mac_label)

        self.client_hostname_label = QLabel()
        layout.addWidget(self.client_hostname_label)

        self.client_link_label = QLabel()
        layout.addWidget(self.client_link_label)

        self.update_info_labels()

        self.timer = QTimer(self)
        self.timer.timeout.connect(self.update_info_labels)
        self.timer.start(INFO_POLLING_INTERVAL)

        self.adjustSize()

    def update_info_labels(self):
        ethernet_interface = get_ethernet_interface()
        client_ip = getifaddr(ethernet_interface)
        client_mac = get_mac_from_interface(ethernet_interface)
        client_hostname = os.uname().nodename
        client_link = ethtool_link_speed(ethernet_interface)

        self.client_ip_label.setText(f'IP: {client_ip}')
        self.client_ip_label.setStyleSheet('font-weight: 600;')
        self.client_mac_label.setText(f'MAC: {client_mac}')
        self.client_mac_label.setStyleSheet('font-weight: 600;')
        self.client_hostname_label.setText(f'HOSTNAME: {client_hostname}')
        self.client_hostname_label.setStyleSheet('font-weight: 600;')

        if client_link < 1000:
            self.client_link_label.setText(f'LINK: {client_link} Mbps')
            self.client_link_label.setStyleSheet('font-weight: 600; color: red;')
        else:
            self.client_link_label.setText(f'LINK: {int(client_link / 1000)} Gbps')
            self.client_link_label.setStyleSheet('font-weight: 600;')